@@ -26,10 +26,11 @@ class PyXploraApi(PyXplora):
         userLang: str,
         timeZone: str,
         childPhoneNumber: List[str] = [],
+        wuid: Any = None,
     ) -> None:
-        super().__init__(countrycode, phoneNumber, password, userLang, timeZone, childPhoneNumber)
+        super().__init__(countrycode, phoneNumber, password, userLang, timeZone, childPhoneNumber, wuid)
 
-    def __login(self, forceLogin: bool = False) -> Dict[Any, Any]:
+    def _login(self, forceLogin: bool = False) -> Dict[Any, Any]:
         if not self._isConnected() or self._hasTokenExpired() or forceLogin:
             try:
                 self._logoff()
@@ -66,7 +67,7 @@ class PyXploraApi(PyXplora):
         return self._issueToken
 
     def init(self, forceLogin: bool = False) -> None:
-        token = self.__login(forceLogin)
+        token = self._login(forceLogin)
         if token:
             if token.get("user", {}):
                 if not self._childPhoneNumber:
@@ -96,6 +97,9 @@ class PyXploraApi(PyXplora):
             self.device[wuid]["locateType"] = self.device[wuid]["loadWatchLocation"].get(
                 "locateType", LocationType.UNKNOWN.value
             )
+            self.device[wuid]["lastTrackTime"] = self.device[wuid]["loadWatchLocation"].get(
+                "tm", datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+            )
             self.device[wuid]["isInSafeZone"] = self.device[wuid]["loadWatchLocation"].get("isInSafeZone", False)
             self.device[wuid]["safeZoneLabel"] = self.device[wuid]["loadWatchLocation"].get("safeZoneLabel", "")
             self.device[wuid]["getWatchSafeZones"] = self.getWatchSafeZones(wuid=wuid)
@@ -634,6 +638,9 @@ class PyXploraApi(PyXplora):
             return {}
         return userSteps
 
+    def getStartTrackingWatch(self, wuid: str):
+        return self._gqlHandler.getStartTrackingWatch(wuid=wuid)
+
     def addStep(self, step: int) -> bool:
         s: Dict[str, bool] = self._gqlHandler.addStep(step)
         return s.get("addStep", False)
