@@ -27,10 +27,11 @@ class PyXploraApi(PyXplora):
         userLang: str,
         timeZone: str,
         childPhoneNumber: List[str] = [],
+        wuid: Any = None,
     ) -> None:
-        super().__init__(countrycode, phoneNumber, password, userLang, timeZone, childPhoneNumber)
+        super().__init__(countrycode, phoneNumber, password, userLang, timeZone, childPhoneNumber, wuid)
 
-    async def __login(self, forceLogin: bool = False) -> Dict[Any, Any]:
+    async def _login(self, forceLogin: bool = False) -> Dict[Any, Any]:
         if not self._isConnected() or self._hasTokenExpired() or forceLogin:
             try:
                 self._logoff()
@@ -67,7 +68,7 @@ class PyXploraApi(PyXplora):
         return self._issueToken
 
     async def init(self, forceLogin: bool = False) -> None:
-        token = await self.__login(forceLogin)
+        token = await self._login(forceLogin)
         if token:
             if token.get("user", {}):
                 if not self._childPhoneNumber:
@@ -90,19 +91,24 @@ class PyXploraApi(PyXplora):
         wuids: List[str] = self.getWatchUserIDs()
         for wuid in wuids:
             self.device[wuid] = {}
-            self.device[wuid]["getWatchAlarm"] = create_task(self.getWatchAlarm(wuid=wuid))
+            self.device[wuid]["getWatchAlarm"] = await create_task(self.getWatchAlarm(wuid=wuid))
             self.device[wuid]["loadWatchLocation"] = await create_task(self.loadWatchLocation(wuid=wuid))
             self.device[wuid]["watch_battery"] = int(self.device[wuid]["loadWatchLocation"].get("watch_battery", -1))
             self.device[wuid]["watch_charging"] = self.device[wuid]["loadWatchLocation"].get("watch_charging", False)
             self.device[wuid]["locateType"] = self.device[wuid]["loadWatchLocation"].get(
                 "locateType", LocationType.UNKNOWN.value
             )
+            self.device[wuid]["lastTrackTime"] = self.device[wuid]["loadWatchLocation"].get(
+                "tm", datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+            )
             self.device[wuid]["isInSafeZone"] = self.device[wuid]["loadWatchLocation"].get("isInSafeZone", False)
             self.device[wuid]["safeZoneLabel"] = self.device[wuid]["loadWatchLocation"].get("safeZoneLabel", "")
-            self.device[wuid]["getWatchSafeZones"] = create_task(self.getWatchSafeZones(wuid=wuid))
-            self.device[wuid]["getSilentTime"] = create_task(self.getSilentTime(wuid=wuid))
+            self.device[wuid]["getWatchSafeZones"] = await create_task(self.getWatchSafeZones(wuid=wuid))
+            self.device[wuid]["getSilentTime"] = await create_task(self.getSilentTime(wuid=wuid))
             self.device[wuid]["getWatches"] = await create_task(self.getWatches(wuid=wuid))
-            self.device[wuid]["getSWInfo"] = create_task(self.getSWInfo(wuid=wuid, watches=self.device[wuid]["getWatches"]))
+            self.device[wuid]["getSWInfo"] = await create_task(
+                self.getSWInfo(wuid=wuid, watches=self.device[wuid]["getWatches"])
+            )
             d = datetime.now()
             dt = datetime(year=d.year, month=d.month, day=d.day)
             self.device[wuid]["getWatchUserSteps"] = await create_task(self.getWatchUserSteps(wuid=wuid, date=dt.timestamp()))
@@ -631,6 +637,10 @@ class PyXploraApi(PyXplora):
             return {}
         return userSteps
 
+    async def getStartTrackingWatch(self, wuid: str):
+        data: Dict[str, Any] = await self._gqlHandler.getStartTrackingWatch_a(wuid)
+        return data.get("startTrackingWatch", "")
+
     async def addStep(self, step: int) -> bool:
         s: Dict[str, bool] = await self._gqlHandler.addStep_a(step)
         return s.get("addStep", False)
